@@ -13,6 +13,8 @@ Options:
 import json
 import logging
 
+import colorful as cf
+
 from .spec import *
 
 
@@ -37,14 +39,14 @@ def check_decorator(category):
     return closure
 
 
-def fail_msg(node, msg):
+def fail_msg(node, msg, level="error"):
     def location(node):
         if node.parent is None:
             return node.name
 
         return location(node.parent) + "/" + node.name
 
-    return f"{location(node)}: {msg}"
+    return (level, f"{location(node)}: {msg}")
 
 
 @check_decorator("sig")
@@ -61,8 +63,14 @@ def signal_start(signal):
 
 @check_decorator("sig")
 def signal_total_length(signal):
-    if signal.length + signal.offset > 64:
-        return fail_msg(signal, f"signal end is bigger than 64")
+    if signal.start + signal.length > 64:
+        level = "error"
+        if signal.byte_order == "big_endian":
+            level = "warning"
+        else:
+            level = "error"
+
+        return fail_msg(signal, f"signal end is bigger than 64", level)
 
 
 @check_decorator("sig")
@@ -120,6 +128,7 @@ def signal_mux_count(sig):
     if int(sig.mux_count) == 0:
         return fail_msg(sig, f"Mux count *cannot* be 0")
 
+
 @check_decorator("msg")
 def msg_mux(msg):
     muxeds = [signal.mux for signal in msg.signals.values() if signal.mux != ""]
@@ -132,7 +141,7 @@ def msg_mux(msg):
 
     if 2 ** mux.length < mux.mux_count:
         return fail_msg(msg, f"Mux cannot fit all possible multiplexed values")
-    
+
 
 @check_decorator("msg")
 def msg_name(msg):
@@ -158,7 +167,6 @@ def msg_frequency(msg):
         return fail_msg(msg, f"Message frequency is not valid: {msg.frequency}")
 
 
-
 @check_decorator("msg")
 def msg_overlapping_signals(msg):
     values = []
@@ -249,6 +257,48 @@ def spec_overlapping_dev_ids(spec):
         return fail_msg(spec, f"There are overlapping device ids")
 
 
+@check_decorator("spec")
+def spec_same_name_configs(spec):
+    cfgs = []
+    for dev in spec.devices.values():
+        for cfg in dev.cfgs.values():
+            cfgs += [cfg.name]
+
+    cfgs_set = set()
+
+    for cfg in cfgs:
+        if cfgs.count(cfg) > 1:
+            cfgs_set.add(cfg)
+
+    if len(cfgs_set) != 0:
+        return fail_msg(
+            spec,
+            "There are overlapping config names [{}]".format(", ".join(cfgs_set)),
+            level="warning",
+        )
+
+
+@check_decorator("spec")
+def spec_same_name_commands(spec):
+    cmds = []
+    for dev in spec.devices.values():
+        for cmd in dev.cmds.values():
+            cmds += [cmd.name]
+
+    cmds_set = set()
+
+    for cmd in cmds:
+        if cmds.count(cmd) > 1:
+            cmds_set.add(cmd)
+
+    if len(cmds_set) != 0:
+        return fail_msg(
+            spec,
+            "There are overlapping command names [{}]".format(", ".join(cmds_set)),
+            level="warning",
+        )
+
+
 def spec_repeated_names(spec):
     def get_signal_names(spec):
         for dev in spec.devices.values():
@@ -278,7 +328,7 @@ def check(category, arg):
     return failed
 
 
-def validate(logger, spec):
+def validate(spec):
     failed = []
     failed += check("spec", spec)
 
@@ -300,3 +350,14 @@ def validate(logger, spec):
             failed += check("cmd", cmd)
 
     return failed
+
+
+def format_error(level, message):
+    if level == "warning":
+        level = cf.yellow(level)
+    elif level == "error":
+        level = cf.red(level)
+    else:
+        level = cf.blue(level)
+
+    return f"{level}: {message}"
